@@ -1,46 +1,75 @@
 setGeneric(".RsamtoolsFileList",
-           function(..., yieldSize=NA_integer_, class)
+           function(file, ..., yieldSize=NA_integer_, class)
                standardGeneric(".RsamtoolsFileList"),
-           signature="...")
+           signature="file")
+
+setMethod(.RsamtoolsFileList, "missing",
+    function(file, ..., classDef = class, yieldSize=NA_integer_, class)
+{
+    new(paste0(class, "List"))
+})
 
 setMethod(.RsamtoolsFileList, "character",
-    function(file, index, ..., yieldSize=NA_integer_, class)
+    function(file, index, ..., classDef=class, yieldSize=NA_integer_, class)
 {
-    fun <- function(elt, ..., yieldSize, class)
-        do.call(class, list(elt, ..., yieldSize=yieldSize))
+    fun <- function(elt, ..., yieldSize, classDef)
+        do.call(classDef, list(elt, ..., yieldSize=yieldSize))
     if (is.null(names(file)))
         names(file) <- basename(file)
     listData <- if (!missing(index) && length(index))
-        Map(fun, file, index, ...,
-            MoreArgs=list(yieldSize=yieldSize, class=class))
+        Map(fun, file, as.character(index), ...,
+            MoreArgs=list(yieldSize=yieldSize, classDef=classDef))
     else if (missing(index))
-        Map(fun, file, ..., MoreArgs=list(yieldSize=yieldSize, class=class))
+        Map(fun, file, ...,
+            MoreArgs=list(yieldSize=yieldSize, classDef=classDef)
+        )
     else
         ## support old index=character() variant
         Map(fun, file, ..., MoreArgs=list(index=index,
-                              yieldSize=yieldSize, class=class))
+                              yieldSize=yieldSize, classDef=classDef))
     new(paste0(class, "List"), listData=listData)
 })
 
 setMethod(.RsamtoolsFileList, "ANY",
-    function(..., yieldSize=NA_integer_, class)
+    function(file, ..., classDef = class, yieldSize=NA_integer_, class)
 {
-    list <- list(...)
+    list <- list(file, ...)
     if (length(list) == 1 && (is.list(list[[1L]]) || is(list[[1L]], "List")))
         list <- as.list(list[[1L]])
     new(paste0(class, "List"), listData=list)
 })
 
+setMethod(.RsamtoolsFileList, "RsamtoolsFile",
+    function(file, ..., classDef = class, yieldSize=NA_integer_, class)
+{
+    new(paste0(class, "List"), listData=list(file, ...))
+})
+
 setMethod(path, "RsamtoolsFileList",
     function(object, ...)
 {
-    sapply(as.list(object), path)
+    vapply(object, path, character(1))
+})
+
+setMethod(index, "RsamtoolsFileList",
+    function(object, ...)
+{
+    sapply(object, index, ...)
+})
+
+setReplaceMethod("index", "RsamtoolsFileList",
+    function(object, ..., value)
+{
+    stopifnot(length(value) == length(path(object)))
+    for (i in seq_along(object))
+        index(object[[i]]) <- value[i]
+    object
 })
 
 setMethod(yieldSize, "RsamtoolsFileList",
     function(object, ...)
 {
-    sapply(as.list(object), yieldSize)
+    vapply(object, yieldSize, numeric(1))
 })
 
 setReplaceMethod("yieldSize", "RsamtoolsFileList", 
@@ -86,11 +115,8 @@ setMethod(names, "RsamtoolsFileList",
 
 BcfFileList <- function(...) .RsamtoolsFileList(..., class="BcfFile")
 
-TabixFileList <-
-    function(..., yieldSize=NA_integer_)
-{
-    .RsamtoolsFileList(..., yieldSize=yieldSize, class="TabixFile")
-}
+TabixFileList <- function(...)
+    .RsamtoolsFileList(..., class="TabixFile")
 
 FaFileList <- function(...) .RsamtoolsFileList(..., class="FaFile")
 
