@@ -21,8 +21,19 @@ library(Rsamtools)
 ###################################################
 ### code chunk number 4: ScanBamParam
 ###################################################
-which <- IRangesList(seq1=IRanges(1000, 2000),
-                     seq2=IRanges(c(100, 1000), c(1000, 2000)))
+which <- GRanges(c(
+    "seq1:1000-2000",
+    "seq2:100-1000",
+    "seq2:1000-2000"
+))
+## equivalent:
+## GRanges(
+##     seqnames = c("seq1", "seq2", "seq2"),
+##     ranges = IRanges(
+##         start = c(1000, 100, 1000),
+##         end = c(2000, 1000, 2000)
+##     )
+## )
 what <- c("rname", "strand", "pos", "qwidth", "seq")
 param <- ScanBamParam(which=which, what=what)
 
@@ -30,8 +41,7 @@ param <- ScanBamParam(which=which, what=what)
 ###################################################
 ### code chunk number 5: scanBam
 ###################################################
-bamFile <- 
-    system.file("extdata", "ex1.bam", package="Rsamtools")
+bamFile <- system.file("extdata", "ex1.bam", package="Rsamtools")
 bam <- scanBam(bamFile, param=param)
 
 
@@ -88,7 +98,7 @@ list.files(dirname(bamFile), pattern="ex1.bam(.bai)?")
 ###################################################
 ### code chunk number 12: bam-remote (eval = FALSE)
 ###################################################
-## which <- IRangesList("6"=IRanges(100000L, 110000L))
+## which <- GRanges("6:100000-110000")
 ## param <- ScanBamParam(which=which, what=scanBamWhat())
 ## na19240bam <- scanBam(na19240url, param=param)
 
@@ -96,12 +106,14 @@ list.files(dirname(bamFile), pattern="ex1.bam(.bai)?")
 ###################################################
 ### code chunk number 13: summaryFunction
 ###################################################
-summaryFunction <- 
+summaryFunction <-
     function(seqname, bamFile, ...)
 {
-    param <- ScanBamParam(what=c('pos', 'qwidth'),
-                          which=GRanges(seqname, IRanges(1, 1e7)),
-                          flag=scanBamFlag(isUnmappedQuery=FALSE))
+    param <- ScanBamParam(
+        what=c('pos', 'qwidth'),
+        which=GRanges(seqname, IRanges(1, 1e7)),
+        flag=scanBamFlag(isUnmappedQuery=FALSE)
+    )
     x <- scanBam(bamFile, ..., param=param)[[1]]
     coverage(IRanges(x[["pos"]], width=x[["qwidth"]]))
 }
@@ -145,8 +157,10 @@ egid <- c("10", "1544", "1548", "1549", "7498", "9")
 ### code chunk number 17: txdb-transcripts
 ###################################################
 library(TxDb.Hsapiens.UCSC.hg18.knownGene)
-bamRanges <- transcripts(TxDb.Hsapiens.UCSC.hg18.knownGene, 
-                         filter=list(gene_id=egid))
+bamRanges <- transcripts(
+    TxDb.Hsapiens.UCSC.hg18.knownGene,
+    filter=list(gene_id=egid)
+)
 seqlevels(bamRanges) <-                 # translate seqlevels
     sub("chr", "", seqlevels(bamRanges))
 lvls <- seqlevels(bamRanges)            # drop unused levels
@@ -165,8 +179,7 @@ unique(genome(bamRanges))
 ### code chunk number 19: BamViews-parts
 ###################################################
 slxMaq09 <- local({
-    fl <- system.file("extdata", "slxMaq09_urls.txt", 
-                      package="Rsamtools")
+    fl <- system.file("extdata", "slxMaq09_urls.txt", package="Rsamtools")
     readLines(fl)
 })
 
@@ -174,12 +187,13 @@ slxMaq09 <- local({
 ###################################################
 ### code chunk number 20: BamViews-construct
 ###################################################
-bamExperiment <- 
+bamExperiment <-
     list(description="Caffeine metabolism views on 1000 genomes samples",
          created=date())
-bv <- BamViews(slxMaq09, bamRanges=bamRanges, 
-               bamExperiment=bamExperiment)
-metadata(bamSamples(bv)) <- 
+bv <- BamViews(
+    slxMaq09, bamRanges=bamRanges, bamExperiment=bamExperiment
+)
+metadata(bamSamples(bv)) <-
     list(description="Solexa/MAQ samples, August 2009",
          created="Thu Mar 25 14:08:42 2010")
 bv
@@ -248,17 +262,18 @@ head(olap1[[24]])
 ###################################################
 minw <- min(sapply(olap1, function(elt) min(start(elt))))
 maxw <- max(sapply(olap1, function(elt) max(end(elt))))
-cvg <- endoapply(olap1, coverage,
-                 shift=-start(ranges(bamRanges[1])),
-                 width=width(ranges(bamRanges[1])))
+cvg <- endoapply(
+    olap1, coverage,
+    shift=-start(ranges(bamRanges[1])),
+    width=width(ranges(bamRanges[1]))
+)
 cvg[[1]]
 
 
 ###################################################
 ### code chunk number 28: olap-cvg-as-m
 ###################################################
-m <- matrix(unlist(lapply(cvg, lapply, as.vector)),
-            ncol=length(cvg))
+m <- matrix(unlist(lapply(cvg, lapply, as.vector)), ncol=length(cvg))
 summary(rowSums(m))
 summary(colSums(m))
 
@@ -274,13 +289,13 @@ sessionInfo()
 ### code chunk number 30: bam-avail (eval = FALSE)
 ###################################################
 ## library(RCurl)
-## ftpBase <- 
+## ftpBase <-
 ##     "ftp://ftp-trace.ncbi.nih.gov/1000genomes/ftp/pilot_data/data/"
-## indivDirs <- 
+## indivDirs <-
 ##     strsplit(getURL(ftpBase, ftplistonly=TRUE), "\n")[[1]]
-## alnDirs <- 
+## alnDirs <-
 ##     paste(ftpBase, indivDirs, "/alignment/", sep="")
-## urls0 <- 
+## urls0 <-
 ##     strsplit(getURL(alnDirs, dirlistonly=TRUE), "\n")
 
 
@@ -296,11 +311,11 @@ sessionInfo()
 ###################################################
 ### code chunk number 32: slxMaq09 (eval = FALSE)
 ###################################################
-## urls1 <- 
-##     Filter(function(x) length(x) != 0,
-##            lapply(urls, 
-##                   function(x) x[grepl("SLX.maq.*2009_08.*bai$", x)]))
-## slxMaq09.bai <- 
+## urls1 <- Filter(
+##     function(x) length(x) != 0,
+##     lapply(urls, function(x) x[grepl("SLX.maq.*2009_08.*bai$", x)])
+## )
+## slxMaq09.bai <-
 ##    mapply(paste, names(urls1), urls1, sep="", USE.NAMES=FALSE)
 ## slxMaq09 <- sub(".bai$", "", slxMaq09.bai) #$
 
@@ -310,8 +325,10 @@ sessionInfo()
 ###################################################
 ## bamIndexDir <- tempfile()
 ## dir.create(bamIndexDir)
-## idxFiles <- mapply(download.file, slxMaq09.bai, 
-##                    file.path(bamIndexDir, basename(slxMaq09.bai)) ,
-##                    MoreArgs=list(method="curl"))
+## idxFiles <- mapply(
+##     download.file, slxMaq09.bai,
+##     file.path(bamIndexDir, basename(slxMaq09.bai)) ,
+##     MoreArgs=list(method="curl")
+## )
 
 
