@@ -7,7 +7,8 @@
 #include <utility>
 #include <algorithm>
 #include <cassert>
-#include <sam.h>
+#include <bam_plbuf.h>
+#include <samtools-1.7-compat.h>
 #include "ResultManager.h"
 #include "utilities.h"
 #include <Rinternals.h>
@@ -53,7 +54,7 @@ private:
     const bool isRanged, isBuffered;
     bool isQueryBin;
     int binsLength;
-    const SEXP schema, pileupParams, seqnamesLevels;
+    const SEXP pileupParams, seqnamesLevels;
     ResultMgrInterface *resultMgr;
     std::vector<int32_t> binPoints;
     int max_depth() const {
@@ -136,11 +137,10 @@ public:
     // void *posCacheColl is dumbly passed through to ResultMgr to
     // give ResultMgr pointer to the struct _BAM_FILE pbuffer member;
     // PileupBuffer doesn't know anything about PosCacheColl
-    Pileup(bool isRanged_, bool isBuffered_, SEXP schema_, SEXP pileupParams_,
+    Pileup(bool isRanged_, bool isBuffered_, SEXP pileupParams_,
            SEXP seqnamesLevels_, PosCacheColl** posCacheColl_)
         : isRanged(isRanged_), isBuffered(isBuffered_), isQueryBin(false),
           binsLength(0),
-          schema(schema_),
           pileupParams(pileupParams_), seqnamesLevels(seqnamesLevels_),
           resultMgr((ResultMgrInterface *) NULL), binPoints()
         {
@@ -182,7 +182,7 @@ public:
         int num_reads_to_process = theDepth < 2 ? 1 : theDepth + 1;
         bam_plp_set_maxcnt(plbuf->iter, num_reads_to_process);
     }
-    static int insert(uint32_t tid, uint32_t pos, int n,
+    static int insert(uint32_t tid, hts_pos_t pos, int n,
                       const bam_pileup1_t *pl, void *data);
     SEXP yield();
     void signalEOI();
